@@ -16,7 +16,7 @@
 
 # You should have received a copy of the GNU General Public License
 # along with Autosubmit.  If not, see <http://www.gnu.org/licenses/>.
-
+import locale
 from os import path
 import os
 from shutil import rmtree
@@ -84,7 +84,7 @@ class AutosubmitGit:
     @staticmethod
     def check_commit(as_conf):
         """
-        Function to check uncommited changes
+        Function to check uncommitted changes
 
         :param as_conf: experiment configuration
         :type as_conf: autosubmitconfigparser.config.AutosubmitConfig
@@ -104,7 +104,7 @@ class AutosubmitGit:
 
                 if output:
                     Log.printlog(
-                        "There are local changes not commited to git", 3000)
+                        "There are local changes not committed to git", 3000)
                     return True
                 else:
                     output = subprocess.check_output("cd {0}; git log --branches --not --remotes".format(dirname_path),
@@ -125,7 +125,7 @@ class AutosubmitGit:
         Clones a specified git repository on the project folder
 
         :param as_conf: experiment configuration
-        :type as_conf: autosubmitconfigparser.config.AutosubmitConfig
+        :type as_conf: autosubmit.config.AutosubmitConfig
         :param force: if True, it will overwrite any existing clone
         :type force: bool
         :param hpcarch: current main platform
@@ -145,6 +145,10 @@ class AutosubmitGit:
             git_project_branch = 'master'
         git_project_commit = as_conf.get_git_project_commit()
         git_project_submodules = as_conf.get_submodules_list()
+        git_project_submodules_depth = as_conf.get_project_submodules_depth()
+        max_depth = -1
+        if len(git_project_submodules_depth) > 0:
+            max_depth = max(git_project_submodules_depth)
         if as_conf.get_fetch_single_branch() != "true":
             git_single_branch = False
         else:
@@ -162,10 +166,10 @@ class AutosubmitGit:
                 Log.info("Making a backup of your current proj folder at {0}".format(
                     project_backup_path))
                 shutil.move(project_path, project_backup_path)
-            # shutil.make_archive(project_backup_path, 'zip', project_path)
-            # project_backup_path = project_backup_path + ".zip"
+            #shutil.make_archive(project_backup_path, 'zip', project_path)
+            #project_backup_path = project_backup_path + ".zip"
 
-        if os.path.exists(project_path):
+        if os.path.exists(os.path.join(project_path,project_destination)):
             Log.info("Using project folder: {0}", project_path)
             # print("Force {0}".format(force))
             if not force:
@@ -173,10 +177,13 @@ class AutosubmitGit:
                 return True
             else:
                 shutil.rmtree(project_path)
-        os.mkdir(project_path)
-        Log.debug("The project folder {0} has been created.", project_path)
+        if not os.path.exists(project_path):
+            os.mkdir(project_path)
+            Log.debug("The project folder {0} has been created.", project_path)
         command_0 = ""
+        command_githook = ""
         command_1 = ""
+
         if git_remote_project_path != '':
             if git_remote_project_path[-1] == '/':
                 git_remote_path = os.path.join(
@@ -195,45 +202,79 @@ class AutosubmitGit:
                                                                              git_project_origin,
                                                                              project_destination)
         try:
-            ## command 0
+            ##command 0
             Log.debug('Clone command: {0}', command_0)
+            try:
+                git_version = subprocess.check_output("git --version",shell=True)
+                git_version = git_version.decode(locale.getlocale()[1]).split(" ")[-1].strip("\n")
 
+                version_int = ""
+                for number in git_version.split("."):
+                    version_int += number
+                git_version = int(version_int)
+            except:
+                git_version = 2251
             if git_remote_project_path == '':
                 command_0 = "cd {0} ; {1}".format(project_path, command_0)
                 output_0 = subprocess.check_output(command_0, shell=True)
             else:
                 command_0 = "cd {0} ; {1}".format(project_path, command_0)
                 hpcarch.send_command(command_0)
-            # command 1
-            if os.path.exists(os.path.join(git_path, ".githooks")):
+            ##command 1
+
+            if os.path.exists(os.path.join(git_path, ".githooks")) and git_version > 2136:
                 for root_dir, dirs, files in os.walk(os.path.join(git_path, ".githooks")):
                     for f_dir in dirs:
                         os.chmod(os.path.join(root_dir, f_dir), 0o750)
                     for f_file in files:
                         os.chmod(os.path.join(root_dir, f_file), 0o750)
-                command_1 += " git config core.hooksPath ./.githooks ; ".format(
+                command_githook += " git config core.hooksPath ./.githooks ; ".format(
                     git_path)
             if git_project_commit:
-                command_1 += "git checkout {0};".format(git_project_commit)
+                command_1 += "git checkout {0}; ".format(git_project_commit)
             else:
                 command_1 += "git checkout; "
+
             if git_project_submodules.__len__() <= 0:
-                command_1 += " git submodule update --init --recursive;"
+                if max_depth > 0:
+                    Log.info("Depth is incompatible with --recursive, ignoring recursive option")
+                    command_1 += " git submodule update --init --depth {0}; ".format(max_depth)
+                else:
+                    command_1 += " git submodule update --init --recursive; "
             else:
-                command_1 += " git submodule init;"
+                command_1 += " git submodule init; ".format(project_destination)
+                index_submodule = 0
                 for submodule in git_project_submodules:
-                    command_1 += " git submodule update --init --recursive {0};".format(submodule)
+                    if max_depth > 0:
+                        Log.info("Depth is incompatible with --recursive, ignoring recursive option")
+                        if index_submodule < len(git_project_submodules_depth):
+                            command_1 += " git submodule update --init --depth {0} {1}; ".format(
+                                git_project_submodules_depth[index_submodule], submodule)
+                        else:
+                            command_1 += " git submodule update --init --depth {0} {1}; ".format(
+                                max_depth, submodule)
+                    else:
+                        command_1 += " git submodule update --init --recursive {0}; ".format(submodule)
+                    index_submodule += 1
             if git_remote_project_path == '':
                 try:
-                    command_1 = "cd {0}; {1} ".format(git_path, command_1)
-                    Log.debug('Githook + Checkout and Submodules: {0}', command_1)
+                    if len(command_githook) > 0:
+                        command_githook = "cd {0} ; {1}".format(git_path, command_githook)
+                        as_conf.parse_githooks()
+                        subprocess.check_output(command_githook, shell=True)
+                    command_1 = "cd {0}; {1} ".format(git_path,command_1)
+                    Log.debug('Githook + Checkout and Submodules: {0}', command_githook, command_1)
                     output_1 = subprocess.check_output(command_1, shell=True)
                 except BaseException as e:
                     submodule_failure = True
                     Log.printlog("Trace: {0}".format(str(e)), 6014)
                     Log.printlog(
-                        "Submodule has a wrong configuration", 6014)
+                        "Submodule has a wrong configuration.\n{0}".format(command_1), 6014)
             else:
+                if len(command_githook) > 0:
+                    command_githook = "cd {0} ; {1}".format(project_path, command_githook)
+                    as_conf.parse_githooks()
+                    hpcarch.send_command(command_githook)
                 command_1 = "cd {0}; {1} ".format(project_path, command_1)
                 hpcarch.send_command(command_1)
         except subprocess.CalledProcessError as e:
@@ -252,3 +293,5 @@ class AutosubmitGit:
             shutil.rmtree(project_backup_path)
 
         return True
+
+
