@@ -173,7 +173,7 @@ class JobPackageBase(object):
             raise
         except BaseException as e: #should be IOERROR
             raise AutosubmitCritical(
-                "Error on {1}, template [{0}] still does not exists in running time(check=on_submission actived) ".format(job.file,job.name), 7014)
+                "Error on {1}, template [{0}] still does not exists in running time(check=on_submission activated) ".format(job.file,job.name), 7014)
         Log.debug("Creating Scripts")
         if not exit_:
             if len(self.jobs) < thread_number:
@@ -220,6 +220,12 @@ class JobPackageSimple(JobPackageBase):
     def _send_files(self):
         for job in self.jobs:
             self.platform.send_file(self._job_scripts[job.name])
+            # TODO Ugly fix quick fix until figure another option, this is to avoid to delete the Additional file in local before sending it due sharing the same directory
+            if self.platform.type.upper() != "LOCAL":
+                for file_n in range(len(job.additional_files)):
+                    filename = os.path.basename(os.path.splitext(job.additional_files[file_n])[0])
+                    full_path = os.path.join(self._tmp_path,filename ) + "_" + job.name[5:]
+                    self.platform.send_file(os.path.join(self._tmp_path, full_path))
 
     def _do_submission(self, job_scripts="", hold=False):
         if len(job_scripts) == 0:
@@ -278,7 +284,7 @@ class JobPackageArray(JobPackageBase):
         self._common_script = None
         self._array_size_id = "[1-" + str(len(jobs)) + "]"
         self._wallclock = '00:00'
-        self._num_processors = '1'
+        self._num_processors = '0'
         for job in jobs:
             if job.wallclock > self._wallclock:
                 self._wallclock = job.wallclock
@@ -361,7 +367,7 @@ class JobPackageThread(JobPackageBase):
         self._job_dependency = dependency
         self._common_script = None
         self._wallclock = '00:00'
-        self._num_processors = '1'
+        self._num_processors = '0'
         self._jobs_resources = jobs_resources
         self._wrapper_factory = self.platform.wrapper
         self.current_wrapper_section = wrapper_section
@@ -408,7 +414,7 @@ class JobPackageThread(JobPackageBase):
         return jobs_scripts
     @property
     def queue(self):
-        if str(self._num_processors) == '1':
+        if str(self._num_processors) == '1' or str(self._num_processors) == '0':
             return self.platform.serial_platform.serial_queue
         else:
             return self._queue
@@ -520,7 +526,7 @@ class JobPackageThreadWrapped(JobPackageThread):
 
     @property
     def queue(self):
-        if str(self._num_processors) == '1':
+        if str(self._num_processors) == '1' or str(self._num_processors) == '0':
             return self.platform.serial_platform.serial_queue
         else:
             return self.platform.queue
@@ -680,7 +686,7 @@ class JobPackageHorizontal(JobPackageThread):
                                                  num_processors=self._num_processors, jobs_scripts=self._jobs_scripts,
                                                  dependency=self._job_dependency, jobs_resources=self._jobs_resources,
                                                  expid=self._expid, rootdir=self.platform.root_dir,
-                                                 directives=self._custom_directives,threads=self._threads,method=self.method.lower())
+                                                 directives=self._custom_directives,threads=self._threads,method=self.method.lower(),partition=self.partition)
 
 class JobPackageHybrid(JobPackageThread):
     """
@@ -725,7 +731,7 @@ class JobPackageVerticalHorizontal(JobPackageHybrid):
                                                  wallclock=self._wallclock, num_processors=self._num_processors,
                                                  jobs_scripts=self._jobs_scripts, dependency=self._job_dependency,
                                                  jobs_resources=self._jobs_resources, expid=self._expid,
-                                                 rootdir=self.platform.root_dir, directives=self._custom_directives,threads=self._threads,method=self.method.lower())
+                                                 rootdir=self.platform.root_dir, directives=self._custom_directives,threads=self._threads,method=self.method.lower(),partition=self.partition)
 
 
 class JobPackageHorizontalVertical(JobPackageHybrid):
@@ -736,5 +742,5 @@ class JobPackageHorizontalVertical(JobPackageHybrid):
                                                  wallclock=self._wallclock, num_processors=self._num_processors,
                                                  jobs_scripts=self._jobs_scripts, dependency=self._job_dependency,
                                                  jobs_resources=self._jobs_resources, expid=self._expid,
-                                                 rootdir=self.platform.root_dir, directives=self._custom_directives,threads=self._threads,method=self.method.lower())
+                                                 rootdir=self.platform.root_dir, directives=self._custom_directives,threads=self._threads,method=self.method.lower(),partition=self.partition)
 
