@@ -1,4 +1,6 @@
 import locale
+from binascii import hexlify
+from contextlib import suppress
 from time import sleep
 import sys
 import socket
@@ -125,8 +127,11 @@ class ParamikoPlatform(Platform):
                 except BaseException as e:
                     message = str(e)
                 if message.find("t accept remote connections") == -1:
-                    transport = self._ssh.get_transport()
-                    transport.send_ignore()
+                    try:
+                        transport = self._ssh.get_transport()
+                        transport.send_ignore()
+                    except:
+                        message = "Timeout connection"
                 return message
         except EOFError as e:
             self.connected = False
@@ -147,8 +152,6 @@ class ParamikoPlatform(Platform):
             retry = 0
             try:
                 self.connect()
-            except SSHException as e:
-                raise
             except Exception as e:
                 if ',' in self.host:
                     Log.printlog("Connection Failed to {0}, will test another host".format(
@@ -168,7 +171,7 @@ class ParamikoPlatform(Platform):
                 raise AutosubmitCritical(
                     'Experiment cant no continue without unexpected behaviour, Stopping Autosubmit', 7050, trace)
 
-        except AutosubmitCritical:
+        except AutosubmitCritical as e:
             raise
         except SSHException as e:
             raise
@@ -176,7 +179,18 @@ class ParamikoPlatform(Platform):
             raise AutosubmitCritical(
                 'Cant connect to this platform due an unknown error', 7050, str(e))
 
-
+    def agent_auth(self,port):
+        """
+        Attempt to authenticate to the given SSH server using the most common authentication methods available. This will always try to use the SSH agent first, and will fall back to using the others methods if that fails.
+        :parameter port: port to connect
+        :return: True if authentication was successful, False otherwise
+        """
+        try:
+            self._ssh.connect(self._host_config['hostname'], port=port, username=self.user, timeout=60, banner_timeout=60)
+        except BaseException as e:
+            Log.warning(f'Failed to authenticate with ssh-agent due to {e}')
+            return False
+        return True
     def connect(self, reconnect=False):
         """
         Creates ssh connection to host
@@ -192,7 +206,6 @@ class ParamikoPlatform(Platform):
             self._ssh = paramiko.SSHClient()
             self._ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
             self._ssh_config = paramiko.SSHConfig()
-
             self._user_config_file = os.path.expanduser("~/.ssh/config")
             if os.path.exists(self._user_config_file):
                 with open(self._user_config_file) as f:
@@ -203,45 +216,44 @@ class ParamikoPlatform(Platform):
                     self._host_config['hostname'] = random.choice(
                         self._host_config['hostname'].split(',')[1:])
                 else:
-                    self._host_config['hostname'] = self._host_config['hostname'].split(',')[
-                        0]
+                    self._host_config['hostname'] = self._host_config['hostname'].split(',')[0]
             if 'identityfile' in self._host_config:
                 self._host_config_id = self._host_config['identityfile']
-
-            if 'proxycommand' in self._host_config:
-                self._proxy = paramiko.ProxyCommand(
-                    self._host_config['proxycommand'])
-                try:
-                    self._ssh.connect(self._host_config['hostname'], 22, username=self.user,
-                                      key_filename=self._host_config_id, sock=self._proxy, timeout=120 , banner_timeout=120)
-                except Exception as e:
-                    self._ssh.connect(self._host_config['hostname'], 22, username=self.user,
-                                      key_filename=self._host_config_id, sock=self._proxy, timeout=120,
-                                      banner_timeout=120,disabled_algorithms={'pubkeys': ['rsa-sha2-256', 'rsa-sha2-512']})
-            else:
-                try:
-                    self._ssh.connect(self._host_config['hostname'], 22, username=self.user,
-                                      key_filename=self._host_config_id, timeout=120 , banner_timeout=120)
-                except Exception as e:
-                    self._ssh.connect(self._host_config['hostname'], 22, username=self.user,
-                                      key_filename=self._host_config_id, timeout=120 , banner_timeout=120,disabled_algorithms={'pubkeys': ['rsa-sha2-256', 'rsa-sha2-512']})
+            port = int(self._host_config.get('port',22))
+            # Agent Auth
+            if not self.agent_auth(port):
+                # Public Key Auth
+                if 'proxycommand' in self._host_config:
+                    self._proxy = paramiko.ProxyCommand(self._host_config['proxycommand'])
+                    try:
+                        self._ssh.connect(self._host_config['hostname'], port, username=self.user,
+                                          key_filename=self._host_config_id, sock=self._proxy, timeout=60 , banner_timeout=60)
+                    except Exception as e:
+                        self._ssh.connect(self._host_config['hostname'], port, username=self.user,
+                                          key_filename=self._host_config_id, sock=self._proxy, timeout=60,
+                                          banner_timeout=60,disabled_algorithms={'pubkeys': ['rsa-sha2-256', 'rsa-sha2-512']})
+                else:
+                    try:
+                        self._ssh.connect(self._host_config['hostname'], port, username=self.user,
+                                          key_filename=self._host_config_id, timeout=60 , banner_timeout=60)
+                    except Exception as e:
+                        self._ssh.connect(self._host_config['hostname'], port, username=self.user,
+                                          key_filename=self._host_config_id, timeout=60 , banner_timeout=60,disabled_algorithms={'pubkeys': ['rsa-sha2-256', 'rsa-sha2-512']})
             self.transport = self._ssh.get_transport()
-            #self.transport = paramiko.Transport((self._host_config['hostname'], 22))
-            #self.transport.connect(username=self.user)
-            window_size = pow(4, 12)  # about ~16MB chunks
-            max_packet_size = pow(4, 12)
-            #self._ftpChannel = self._ssh.open_sftp()
-            self._ftpChannel = paramiko.SFTPClient.from_transport(self.transport,window_size=window_size,max_packet_size=max_packet_size)
+            self.transport.banner_timeout = 60
+
+            self._ftpChannel = paramiko.SFTPClient.from_transport(self.transport,window_size=pow(4, 12) ,max_packet_size=pow(4, 12) )
+            self._ftpChannel.get_channel().settimeout(120)
             self.connected = True
         except SSHException as e:
             raise
         except IOError as e:
-            if "refused" in e.strerror.lower():
+            if "refused" in str(e.strerror).lower():
                 raise SSHException(" {0} doesn't accept remote connections. Check if there is an typo in the hostname".format(self.host))
-            elif "name or service not known" in e.strerror.lower():
+            elif "name or service not known" in str(e.strerror).lower():
                 raise SSHException(" {0} doesn't accept remote connections. Check if there is an typo in the hostname".format(self.host))
             else:
-                raise AutosubmitError("File can't be located due an slow connection", 6016, str(e))
+                raise AutosubmitError("File can't be located due an slow or timeout connection", 6016, str(e))
         except BaseException as e:
             self.connected = False
             if "Authentication failed." in str(e):
@@ -534,8 +546,8 @@ class ParamikoPlatform(Platform):
                         job.start_time = datetime.datetime.now() # URi: start time
                     if job.start_time is not None and str(job.wrapper_type).lower() == "none":
                         wallclock = job.wallclock
-                        if job.wallclock == "00:00":
-                            wallclock == job.platform.max_wallclock
+                        if job.wallclock == "00:00" or job.wallclock is None:
+                            wallclock = job.platform.max_wallclock
                         if wallclock != "00:00" and wallclock != "00:00:00" and wallclock != "":
                             if job.is_over_wallclock(job.start_time,wallclock):
                                 try:
@@ -652,6 +664,12 @@ class ParamikoPlatform(Platform):
                             try:
                                 job.platform.get_completed_files(job.name)
                                 job_status = job.check_completion(over_wallclock=True)
+                                if job_status is Status.FAILED:
+                                    try:
+                                        job.platform.send_command(
+                                            self.platform.cancel_cmd + " " + str(job.id))
+                                    except:
+                                        pass
                             except:
                                 job_status = Status.FAILED
                 if job_status in self.job_status['COMPLETED']:
@@ -1103,7 +1121,7 @@ class ParamikoPlatform(Platform):
         """
         Gets command to check if a job is running given process identifier
 
-        :param job_id: process indentifier
+        :param job_id: process identifier
         :type job_id: int
         :return: command to check job status script
         :rtype: str
@@ -1174,6 +1192,9 @@ class ParamikoPlatform(Platform):
         if hasattr(self.header, 'get_account_directive'):
             header = header.replace(
                 '%ACCOUNT_DIRECTIVE%', self.header.get_account_directive(job))
+        if hasattr(self.header, 'get_nodes_directive'):
+            header = header.replace(
+                '%NODES_DIRECTIVE%', self.header.get_nodes_directive(job))
         if hasattr(self.header, 'get_memory_directive'):
             header = header.replace(
                 '%MEMORY_DIRECTIVE%', self.header.get_memory_directive(job))
@@ -1225,7 +1246,7 @@ class ParamikoPlatform(Platform):
     
     def check_remote_permissions(self):
         try:
-            path = os.path.join(self.scratch, self.project, self.user, "permission_checker_azxbyc")
+            path = os.path.join(self.scratch, self.project_dir, self.user, "permission_checker_azxbyc")
             try:
                 self._ftpChannel.mkdir(path)
                 self._ftpChannel.rmdir(path)
