@@ -82,13 +82,13 @@ class ParamikoSubmitter(Submitter):
         platforms_used.append(hpcarch)
 
         # Traverse jobs defined in jobs_.conf and add platforms found if not already included
-        jobs_data = exp_data['JOBS']
+        jobs_data = exp_data.get('JOBS', {})
         for job in jobs_data:
             hpc = jobs_data[job].get('PLATFORM', hpcarch).upper()
             if hpc not in platforms_used:
                 platforms_used.append(hpc)
 
-        platform_data = exp_data['PLATFORMS']
+        platform_data = exp_data.get('PLATFORMS', {})
         # Declare platforms dictionary, key: Platform Name, Value: Platform Object
         platforms = dict()
 
@@ -176,9 +176,14 @@ class ParamikoSubmitter(Submitter):
             remote_platform.exclusivity = platform_data[section].get('EXCLUSIVITY', "")
             remote_platform.user = platform_data[section].get('USER', "")
             remote_platform.scratch = platform_data[section].get('SCRATCH_DIR', "")
+            remote_platform.project_dir = platform_data[section].get('SCRATCH_PROJECT_DIR', remote_platform.project)
             remote_platform.temp_dir = platform_data[section].get('TEMP_DIR', "")
             remote_platform._default_queue = platform_data[section].get('QUEUE', "")
             remote_platform._serial_queue = platform_data[section].get('SERIAL_QUEUE', "")
+            remote_platform.ec_queue = platform_data[section].get('EC_QUEUE', "hpc")
+
+            remote_platform.ec_queue = platform_data[section].get('EC_QUEUE', "hpc")
+
             remote_platform.processors_per_node = platform_data[section].get('PROCESSORS_PER_NODE',"1")
             remote_platform.custom_directives = platform_data[section].get('CUSTOM_DIRECTIVES',"")
             if len(remote_platform.custom_directives) > 0:
