@@ -28,6 +28,7 @@ class Platform(object):
         self._serial_platform = None
         self._serial_queue = None
         self._default_queue = None
+        self.ec_queue = "hpc"
         self.processors_per_node = "1"
         self.scratch_free_space = None
         self.custom_directives = None
@@ -39,6 +40,7 @@ class Platform(object):
         self.exclusivity = ''
         self.type = ''
         self.scratch = ''
+        self.project_dir = ''
         self.temp_dir = ''
         self.root_dir = ''
         self.service = None
@@ -251,6 +253,8 @@ class Platform(object):
         parameters['{0}ARCH'.format(prefix)] = self.name
         parameters['{0}HOST'.format(prefix)] = self.host
         parameters['{0}QUEUE'.format(prefix)] = self.queue
+        parameters['{0}EC_QUEUE'.format(prefix)] = self.ec_queue
+
         parameters['{0}USER'.format(prefix)] = self.user
         parameters['{0}PROJ'.format(prefix)] = self.project
         parameters['{0}BUDG'.format(prefix)] = self.budget
@@ -423,7 +427,7 @@ class Platform(object):
         :type retries: int
         :param job_name: name of job to check
         :type job_name: str
-        :return: True if succesful, False otherwise
+        :return: True if successful, False otherwise
         :rtype: bool
         """
         filename = job_name + '_STAT'
@@ -446,7 +450,7 @@ class Platform(object):
          :type retries: int
          :param job_name: name of job to check
          :type job_name: str
-         :return: True if succesful, False otherwise
+         :return: True if successful, False otherwise
          :rtype: bool
          """
         filename = job_name
@@ -463,7 +467,7 @@ class Platform(object):
         :type retries: int
         :param job_name: name of job to check
         :type job_name: str
-        :return: True if succesful, False otherwise
+        :return: True if successful, False otherwise
         :rtype: bool
         """
         filename = job_name
@@ -606,4 +610,4 @@ class Platform(object):
         """
         Sends a Submit file Script, execute it  in the platform and retrieves the Jobs_ID of all jobs at once.
         """
-        raise NotImplementedError
\ No newline at end of file
+        raise NotImplementedError
