@@ -280,7 +280,7 @@ class SlurmPlatform(ParamikoPlatform):
         Updates commands for platforms
         """
         self.root_dir = os.path.join(
-            self.scratch, self.project, self.user, self.expid)
+            self.scratch, self.project_dir, self.user, self.expid)
         self.remote_log_dir = os.path.join(self.root_dir, "LOG_" + self.expid)
         self.cancel_cmd = "scancel"
         self._checkhost_cmd = "echo 1"
@@ -622,7 +622,7 @@ class SlurmPlatform(ParamikoPlatform):
 
     @staticmethod
     def allocated_nodes():
-        return """os.system("scontrol show hostnames $SLURM_JOB_NODELIST > node_list")"""
+        return """os.system("scontrol show hostnames $SLURM_JOB_NODELIST > node_list_{0}".format(node_id))"""
 
     def check_file_exists(self, filename,wrapper_failed=False):
         file_exist = False
