@@ -166,8 +166,9 @@ class TestJob(TestCase):
         self.job.parameters['NUMTASK'] = 666
 
         self.job._tmp_path = '/dummy/tmp/path'
+        self.job.additional_files = '/dummy/tmp/path_additional_file'
 
-        update_content_mock = Mock(return_value='some-content: %NUMPROC%, %NUMTHREADS%, %NUMTASK% %% %%')
+        update_content_mock = Mock(return_value=('some-content: %NUMPROC%, %NUMTHREADS%, %NUMTASK% %% %%',['some-content: %NUMPROC%, %NUMTHREADS%, %NUMTASK% %% %%']))
         self.job.update_content = update_content_mock
 
         config = Mock(spec=AutosubmitConfig)
@@ -183,15 +184,17 @@ class TestJob(TestCase):
             self.job.create_script(config)
         # assert
         update_content_mock.assert_called_with(config)
+        # TODO add assert for additional files
         open_mock.assert_called_with(os.path.join(self.job._tmp_path, self.job.name + '.cmd'), 'wb')
+        # Expected values: %% -> %, %KEY% -> KEY.VALUE without %
         write_mock.write.assert_called_with(b'some-content: 999, 777, 666 % %')
         chmod_mock.assert_called_with(os.path.join(self.job._tmp_path, self.job.name + '.cmd'), 0o755)
 
     def test_that_check_script_returns_false_when_there_is_an_unbound_template_variable(self):
         # arrange
-        update_content_mock = Mock(return_value='some-content: %UNBOUND%')
+        update_content_mock = Mock(return_value=('some-content: %UNBOUND%','some-content: %UNBOUND%'))
         self.job.update_content = update_content_mock
-
+        #template_content = update_content_mock
         update_parameters_mock = Mock(return_value=self.job.parameters)
         self.job.update_parameters = update_parameters_mock
 
@@ -213,7 +216,8 @@ class TestJob(TestCase):
         self.job.parameters['NUMTHREADS'] = 777
         self.job.parameters['NUMTASK'] = 666
 
-        update_content_mock = Mock(return_value='some-content: %NUMPROC%, %NUMTHREADS%, %NUMTASK%')
+        update_content_mock = Mock(return_value=('some-content: %NUMPROC%, %NUMTHREADS%, %NUMTASK%','some-content: %NUMPROC%, %NUMTHREADS%, %NUMTASK%'))
+        #todo
         self.job.update_content = update_content_mock
 
         update_parameters_mock = Mock(return_value=self.job.parameters)
@@ -258,8 +262,9 @@ class TestJob(TestCase):
         # This test (and feature) was implemented in order to avoid
         # false positives on the checking process with auto-ecearth3
         # Arrange
-        section = "random-section"
-        self.job.section = "random-section"
+        section = "RANDOM-SECTION"
+        self.job.section = section
+        self.job.parameters['ROOTDIR'] = "none"
         self.job.parameters['PROJECT_TYPE'] = "none"
         processors = 80
         threads = 1
@@ -274,7 +279,8 @@ class TestJob(TestCase):
             'TASKS': tasks,
             'MEMORY': memory,
             'WALLCLOCK': wallclock,
-            'CUSTOM_DIRECTIVES': custom_directives
+            'CUSTOM_DIRECTIVES': custom_directives,
+            'SCRATCH_FREE_SPACE': 0
         }
         self.as_conf.jobs_data[section] = options
 
@@ -282,12 +288,15 @@ class TestJob(TestCase):
         dummy_serial_platform.name = 'serial'
         dummy_platform = MagicMock()
         dummy_platform.serial_platform = dummy_serial_platform
+        self.as_conf.substitute_dynamic_variables = MagicMock()
+        self.as_conf.substitute_dynamic_variables.return_value = {'d': '%d%', 'd_': '%d_%', 'Y': '%Y%', 'Y_': '%Y_%',
+                                              'M': '%M%', 'M_': '%M_%', 'm': '%m%', 'm_': '%m_%'}
         dummy_platform.custom_directives = '["whatever"]'
         self.as_conf.dynamic_variables = MagicMock()
         self.job._platform = dummy_platform
-
+        parameters = {}
         # Act
-        parameters = self.job.update_parameters(self.as_conf, dict())
+        parameters = self.job.update_parameters(self.as_conf, parameters)
         # Assert
         self.assertTrue('d' in parameters)
         self.assertTrue('d_' in parameters)
