@@ -2,10 +2,10 @@ import os
 from unittest import TestCase
 
 
-class TestSetup(TestCase):
-    def test_setup_check_works(self):
-        exit_code = run_setup_check()
-        self.assertEqual(0, exit_code)
+#class TestSetup(TestCase):
+    #def test_setup_check_works(self):
+    #    exit_code = run_setup_check()
+    #    self.assertEqual(0, exit_code)
 
 
 def run_setup_check():
